<?php

namespace Drupal\confirm_unpublish\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

class ConfirmUnpublishSettingsForm extends ConfigFormBase {
  protected function getEditableConfigNames() {
    return ['confirm_unpublish.settings'];
  }

  public function getFormId() {
    return 'confirm_unpublish_settings_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('confirm_unpublish.settings');

    // Get all available content types.
    $content_types = NodeType::loadMultiple();
    $content_type_options = [];
    foreach ($content_types as $type) {
      $content_type_options[$type->id()] = $type->label();
    }

    // Alert text field (CKEditor enabled).
    $form['alert_text'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Confirmation message'),
      '#description' => $this->t('This message will appear in the unpublish confirmation dialog.'),
      '#default_value' => $config->get('alert_text') ?? 'Are you sure you want to unpublish this node?',
      '#format' => $config->get('alert_text_format') ?: 'basic_html',
      '#required' => TRUE,
    ];

    // Negating checkbox list for content types (exclude content types from confirmation).
    $form['allowed_content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content types to exclude from the confirmation dialog'),
      '#description' => $this->t('Select content types to exclude from the unpublish confirmation dialog. All content types are included by default.'),
      '#options' => $content_type_options,
      '#default_value' => $config->get('allowed_content_types') ?? [],
    ];

    // Checkbox to log unpublishing actions to watchdog.
    $form['logging'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Log unpublishing actions to <a href="/admin/reports/dblog" target="_blank">Recent Log Messages</a>.'),
      '#description' => $this->t('This will log the user who confirmed the unpublish action.  E.g. "User %user confirmed unpublish of %alias."'),
      '#default_value' => $config->get('logging'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValue('alert_text');

    $this->config('confirm_unpublish.settings')
      ->set('alert_text', $values['value'])
      ->set('alert_text_format', $values['format'])
      ->set('logging', $form_state->getValue('logging'))
      ->set('allowed_content_types', $form_state->getValue('allowed_content_types'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}

